@@ -78,6 +78,8 @@ struct _GladeBaseEditorPrivate
 	gint row;
 	
 	gboolean updating_treeview;
+
+	guint properties_idle;
 };
 
 typedef struct _GladeBaseEditorSignal     GladeBaseEditorSignal;
@@ -350,7 +352,9 @@ glade_base_editor_treeview_cursor_changed (GtkTreeView *treeview,
 	GObject *child;
 	GladeWidget *gchild;
 
-	if (! glade_base_editor_get_child_selected (editor, &iter))
+	g_return_if_fail (GTK_IS_TREE_VIEW (treeview));
+
+	if (!glade_base_editor_get_child_selected (editor, &iter))
 		return;
 
 	glade_base_editor_clear (editor);
@@ -372,15 +376,21 @@ glade_base_editor_treeview_cursor_changed (GtkTreeView *treeview,
 static gboolean
 glade_base_editor_update_properties_idle (gpointer data)
 {
-       glade_base_editor_treeview_cursor_changed (NULL, (GladeBaseEditor *)data);
-       return FALSE;
+	GladeBaseEditor *editor = (GladeBaseEditor *)data;
+	glade_base_editor_treeview_cursor_changed (NULL, editor);
+	editor->priv->properties_idle = 0;
+	return FALSE;
 }
 
 
 static void 
 glade_base_editor_update_properties (GladeBaseEditor *editor)
 {
-       g_idle_add (glade_base_editor_update_properties_idle, editor);
+	g_return_if_fail (GLADE_IS_BASE_EDITOR (editor));
+
+	if (!editor->priv->properties_idle)
+		editor->priv->properties_idle = 
+			g_idle_add (glade_base_editor_update_properties_idle, editor);
 }
 
 static void
@@ -993,6 +1003,12 @@ glade_base_editor_project_disconnect (GladeBaseEditor *editor)
 	
 	g_signal_handlers_disconnect_by_func (e->project,
 			glade_base_editor_project_changed, editor);
+
+
+	if (e->properties_idle)
+		g_source_remove (e->properties_idle);
+	e->properties_idle = 0;
+
 }
 
 static void
@@ -1234,7 +1250,7 @@ glade_base_editor_class_init (GladeBaseEditorClass *klass)
 	 * @child: the #GObject being changed.
          * @type: the new type for @child.
 	 *
-	 * Returns TRUE to stop signal emision.
+	 * Returns: TRUE to stop signal emision.
 	 */
 	glade_base_editor_signals [SIGNAL_CHANGE_TYPE] =
 		g_signal_new ("change-type",
@@ -1253,7 +1269,7 @@ glade_base_editor_class_init (GladeBaseEditorClass *klass)
 	 * @gchild: the child to get display name string to show in @gladebaseeditor
 	 * treeview.
 	 *
-	 * Returns a newly allocated string.
+	 * Returns: a newly allocated string.
 	 */
 	glade_base_editor_signals [SIGNAL_GET_DISPLAY_NAME] =
 		g_signal_new ("get-display-name",
@@ -1274,7 +1290,8 @@ glade_base_editor_class_init (GladeBaseEditorClass *klass)
 	 *
 	 * Create a child widget here if something else must be done other than
 	 * calling glade_command_create() such as creating an intermediate parent.
-	 * Returns the newly created #GladeWidget or NULL if child cant be created
+	 *
+	 * Returns: the newly created #GladeWidget or NULL if child cant be created
 	 */
 	glade_base_editor_signals [SIGNAL_BUILD_CHILD] =
 		g_signal_new ("build-child",
@@ -1311,7 +1328,8 @@ glade_base_editor_class_init (GladeBaseEditorClass *klass)
 	 * @gchild: the #GladeWidget to move
 	 *
 	 * Move child here if something else must be done other than cut & paste.
-	 * Returns wheater child has been sucessfully moved or not.
+	 *
+	 * Returns: wheater child has been sucessfully moved or not.
 	 */
 	glade_base_editor_signals [SIGNAL_MOVE_CHILD] =
 		g_signal_new ("move-child",
@@ -1515,7 +1533,7 @@ glade_base_editor_get_type ()
  *   o The type name
  *   o The GType the editor will support
  *
- * Returns a new GladeBaseEditor.
+ * Returns: a new GladeBaseEditor.
  */
 GladeBaseEditor *
 glade_base_editor_new (GObject *container, gboolean tree_like, ...)
@@ -1659,10 +1677,10 @@ glade_base_editor_add_properties (GladeBaseEditor *editor,
 	
 	while (property)
 	{
-		eprop = glade_editor_property_new_from_widget (gchild, property, packing, TRUE);
+		eprop = glade_widget_create_editor_property (gchild, property, packing, TRUE);
 		if (eprop)
 			glade_base_editor_table_attach (editor, 
-							GLADE_EDITOR_PROPERTY (eprop)->eventbox, 
+							GLADE_EDITOR_PROPERTY (eprop)->item_label,
 							GTK_WIDGET (eprop));
 		property = va_arg (args, gchar *);
 	}
@@ -1811,7 +1829,8 @@ glade_base_editor_help (GtkButton *button, gchar *markup)
  * @help_markup: the help text
  *
  * This convenience function create a new modal window and packs @editor in it.
- * Returns the newly created window
+ *
+ * Returns: the newly created window
  */ 
 GtkWidget *
 glade_base_editor_pack_new_window (GladeBaseEditor *editor,
